@@ -44,7 +44,7 @@
  *
  * Since: 0.2
  */
-#define PAROLE_MAJOR_VERSION		0
+#define PAROLE_MAJOR_VERSION		1
 
 /**
  * PAROLE_MINOR_VERSION:
@@ -53,7 +53,7 @@
  *
  * Since: 0.2
  */
-#define PAROLE_MINOR_VERSION		9
+#define PAROLE_MINOR_VERSION		0
 
 /**
  * PAROLE_MICRO_VERSION:
@@ -62,7 +62,7 @@
  *
  * Since: 0.2
  */
-#define PAROLE_MICRO_VERSION		2
+#define PAROLE_MICRO_VERSION		3
 
 /**
  * PAROLE_CHECK_VERSION:
@@ -177,12 +177,12 @@ type_name##_register_type (ParoleProviderPlugin *provider_plugin_def) 		\
 	sizeof (TypeName##Class), 						\
 	NULL, 									\
 	NULL, 									\
-	(GClassInitFunc) type_name##_class_intern_init, 			\
+	(GClassInitFunc) (void (*)(void)) type_name##_class_intern_init, 			\
 	NULL, 									\
 	NULL, 									\
 	sizeof (TypeName), 							\
 	0, 									\
-	(GInstanceInitFunc) type_name##_init, 					\
+	(GInstanceInitFunc) (void (*)(void)) type_name##_init, 					\
 	NULL, 									\
     }; 										\
 										\
@@ -211,7 +211,7 @@ type_name##_register_type (ParoleProviderPlugin *provider_plugin_def) 		\
 { 										\
     static const GInterfaceInfo parole_implement_interface_info = 		\
     { 										\
-	(GInterfaceInitFunc) iface_init 					\
+	(GInterfaceInitFunc) (void (*)(void)) iface_init 					\
     }; 										\
 										\
     g_type_module_add_interface ((GTypeModule*)provider_plugin_def, 		\
